drop table if exists m_adjust_result;

drop table if exists m_major_apply;

drop table if exists m_major_info;

drop table if exists m_schedule_arrange;

drop table if exists m_special_apply;

drop table if exists m_student_info;


/*==============================================================*/
/* Table: m_adjust_result                                       */
/*==============================================================*/
create table m_adjust_result
(
    batch_id             char(8) comment '分流批次',
    student_id           varchar(32) comment '学生id',
    admit_major_id       varchar(32) comment '录取专业',
    special_flag         tinyint comment '是否特殊审批',
    adjust_flag          tinyint comment '是否调剂分配',
    college_id           bigint(20) comment '学院id'
);

alter table m_adjust_result comment '分流结果表';

/*==============================================================*/
/* Table: m_major_apply                                         */
/*==============================================================*/
create table m_major_apply
(
    major_apply_id       varchar(32),
    student_id           varchar(32) comment '学生id',
    major_id_1st         varchar(32) comment '第一志愿',
    major_id_2nd         varchar(32) comment '第二志愿',
    major_id_3rd         varchar(32) comment '第三志愿',
    major_id_4th         varchar(32) comment '第四志愿',
    major_id_5th         varchar(32) comment '第五志愿',
    sign                 text comment '学生签名',
    apply_status         char(1) comment '申请状态（0未提交 1已提交 2通过 3驳回）',
    status               char(1) comment '状态（1启用 0弃用）',
    apply_date           datetime comment '申请时间',
    create_time          datetime comment '创建时间',
    update_time          datetime comment '更新时间'
);

alter table m_major_apply comment '专业分流申请表';

/*==============================================================*/
/* Table: m_major_info                                          */
/*==============================================================*/
create table m_major_info
(
    major_id             varchar(32) comment '专业id',
    major_name           varchar(32) comment '专业名称',
    plan_num             int comment '计划数',
    status               char(1) comment '状态',
    create_time          datetime comment '创建时间',
    update_time          datetime comment '更新时间',
    update_user_id       varchar(32) comment '更新用户',
    create_user_id       varchar(32) comment '创建用户',
    college_id           bigint(20) comment '学院id'
);

alter table m_major_info comment '专业信息表';

/*==============================================================*/
/* Table: m_schedule_arrange                                    */
/*==============================================================*/
create table m_schedule_arrange
(
    orgin_id             varchar(32) comment '源数据id',
    schedule_id          int comment '日程id',
    schedule_name        varchar(32) comment '日程名称',
    year                 varchar(4) comment '年份',
    start_date           date comment '开始时间',
    end_date             date comment '结束时间',
    status               tinyint comment '状态',
    create_time          datetime comment '创建时间',
    update_time          datetime comment '更新时间',
    update_user_id       varchar(32) comment '更新用户',
    create_user_id       varchar(32) comment '创建用户',
    college_id           bigint(20) comment '学院id'
);

alter table m_schedule_arrange comment '日程安排';

/*==============================================================*/
/* Table: m_special_apply                                       */
/*==============================================================*/
create table m_special_apply
(
    special_apply_id     varchar(32),
    student_id           varchar(32) comment '学生id',
    major_id             varchar(32) comment '专业id',
    apply_reason         text comment '申请原因',
    college_opinion      text comment '学院意见（保留字段）',
    aca_affairs_opinion  text comment '教导处意见（保留字段）',
    leader_opinion       text comment '领导意见（保留字段）',
    sign                 text comment '学生签名',
    guardin_sign         text comment '领导签名',
    apply_status         char(1) comment '申请状态（0未提交 1已提交 2通过 3驳回）',
    status               char(1) comment '状态（1启用 0弃用）',
    apply_date           datetime comment '提交时间',
    create_time          datetime comment '创建时间',
    update_time          datetime comment '更新时间',
    update_user_id       char(10) comment '更新用户'
);

alter table m_special_apply comment '特别申请';

/*==============================================================*/
/* Table: m_student_info                                        */
/*==============================================================*/
create table m_student_info
(
    orgin_id             varchar(32) comment '源数据id',
    open_id              varchar(48),
    student_id           varchar(32) comment '学号',
    student_name         char(10) comment '学生名称',
    class_name           varchar(32) comment '班级名称',
    score                decimal(4,4) comment '绩点',
    `rank`                 int comment '排名',
    phonenumber          char(11) comment '联系号码',
    email                varchar(50) comment '邮箱',
    gender               char(1) comment '性别',
    guardian_phone       char(11) comment '监护人号码',
    create_time          datetime comment '创建时间',
    update_time          datetime comment '更新时间',
    create_user_id       varchar(32) comment '创建用户',
    update_user_id       varchar(32) comment '更新用户id',
    college_id           bigint(20) comment '学院id'
);

alter table m_student_info comment '学生信息表';